import io
import pickle


class Book:
    title = ""
    isbn = ""
    parts = None
    chapters = None

    def __init__(self, title, isbn, parts, chapters):
        self.title = title
        self.isbn = isbn
        self.parts = parts
        self.chapters = chapters

    def identify(self):
        print("Title of the book: %s" % (self.title))
        print("ISBN of the book: %s" % (self.isbn))
        print("Parts are:")
        for part in self.parts:
            print(part)
        print("Chapters are:%s" % (self.chapters))


class Part:
    partName = ""
    beginChapter = -1
    endChapter = -1

    def __init__(self, partName, beginChapter, endChapter):
        self.partName = partName
        self.beginChapter = beginChapter
        self.endChapter = endChapter

    def __str__(self):
        stringRep = "%s" % (self.partName)
        return stringRep


part1 = Part("Part 1", 1, 3)
part2 = Part("Part 2", 4, 5)
part3 = Part("Part 3", 6, 7)
bookTitle = "Book yet to be written"
bookISBN = "XXX-X-XX-XXXXXX-X"
bookParts = [part1, part2, part3]
bookChapters = [
    "Chapter 1",
    "Chapter 2",
    "Chapter 3",
    "Chapter 4",
    "Chapter 5",
    "Chapter 6",
    "Chapter 7",
]
book = Book(bookTitle, bookISBN, bookParts, bookChapters)
pickleBuffer = io.BytesIO()
print("Pickling of the object into the memory buffer started")
pickle.dump(book, pickleBuffer)
print("Pickling of the object into the memory buffer ended")
print("Pickled buffer beginning address:")
print(pickleBuffer.getbuffer())
print("Unpickling of the object from memory started")
unpickledBook = pickle.loads(pickleBuffer.getbuffer())
print("Unpickling of the object from memory ended")
print("Printing the attributes of unpickled object")
unpickledBook.identify()



import bisect
import io
import logging
import pathlib
import pickle
import random
import sys
import typing

import appdirs
import requests

from clinepunk import cache as cachemod
from clinepunk import model

url = "https://raw.githubusercontent.com/first20hours/google-10000-english/master/google-10000-english-no-swears.txt"


def refresh_cache() -> typing.List[model.Word]:
    logging.debug(f"fetching {url}")
    response = requests.get(url)
    logging.debug(f"{response.status_code=}")
    if response.status_code != 200:
        logging.warning(f"couldn't fetch {url}")

    text = response.text

    words = []
    for word in text.splitlines():
        bisect.insort(words, model.Word(length=len(word), word=word))

    col = model.WordCollection(words)
    buffer = io.BytesIO()
    pickle.dump(col, buffer)

    return buffer


def find_filter(words, min_length=3, max_length=7):
    return filter(lambda s: s.length > min_length and s.length <= max_length, words)


def get_words(count=2):
    cache_path = pathlib.Path(appdirs.user_cache_dir(appname="clinepunk"))
    buffer = cachemod.cache(cache_path, refresh_cache, "clinepunk.words2")
    print(type(buffer))
    col = pickle.loads(buffer.getbuffer())
    logging.debug(f"word collection has {len(col.words)} words")
    print(type(col))
    words = list(find_filter(col.words))
    logging.debug(f"{len(words)} match query")

    sample = random.sample(words, count)

    return [x.word for x in sample]


def main():
    logging.basicConfig(
        level=logging.DEBUG,
        format="{%(filename)s:%(lineno)d} %(levelname)s - %(message)s",
        handlers=[
            logging.FileHandler(f"{pathlib.Path(__file__).stem}.log"),
            logging.StreamHandler(sys.stdout),
        ],
    )
    lst = get_words(count=2)
    out = "".join(lst)
    logging.debug(out)
    return out


if __name__ == "__main__":
    main()



from dataclasses import dataclass, field
from typing import List


@dataclass(order=True)
class Word:
    length: int = field(compare=True)
    word: str


@dataclass
class WordCollection:
    words: List[Word] = field(default_factory=list)



import datetime
import logging

import diskcache


def cache(cache_path, fcn_refresh, key) -> str:
    with diskcache.Cache(cache_path) as reference:
        logging.debug(f"fetching cache from {key}")
        if not reference.get(key):
            logging.debug("setting cache")
            buffer = fcn_refresh()
            reference.set(
                key,
                buffer,
                expire=datetime.timedelta(days=365 * 2).total_seconds(),
            )
        logging.debug("cache is still fresh, using it")
        return reference.get(key)



import io
import pickle

from clinepunk import model

lst = [
    model.Word(word="test", length=4),
    model.Word(word="better", length=6),
]

col = model.WordCollection(lst)
pickleBuffer = io.BytesIO()
pickle.dump(col, pickleBuffer)
unpickled = pickle.loads(pickleBuffer.getbuffer())
print(unpickled)



"""Console script for clinepunk."""
import sys

import click

from clinepunk import clinepunk


@click.command()
def main(args=None):
    """Console script for clinepunk."""
    words = clinepunk.get_words(count=2)
    out = "".join(words)
    print(out)

    return 0


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover


if __name__ == "__main__":
    main()



import json
import logging
import pathlib
import random
import sys

import appdirs
import humanfriendly
import requests

from clinepunk import cache as cachemod

cache_path = pathlib.Path(appdirs.user_cache_dir(appname="clinepunk"))
url = "https://raw.githubusercontent.com/adambom/dictionary/master/dictionary.json"


def refresh_cache():
    r = requests.get(url)

    if r.status_code == 200:
        dct = r.json()
        js = json.dumps(dct, indent=2).encode("utf-8")
        return js
    return ""


def get_words(count=2):
    js = cachemod.cache(cache_path, refresh_cache, "clinepunk.words")
    words = json.loads(js)
    words = words.keys()
    words = list(filter(lambda x: len(x) <= 7, words))

    logging.debug(f"cache path is {cache_path}")
    logging.debug(f"cache has {len(words):,d} words")
    logging.debug(
        f"cache has size {humanfriendly.format_size(cache_path.stat().st_size, binary=True)}"
    )

    remove = ["-", "sex"]
    sample = random.sample(words, count)
    for word in remove:
        if word in "".join(sample):
            sample = random.sample(words, count)

    logging.debug(f"sample words is {sample}")

    return [x.lower() for x in sample]


def main():
    logging.basicConfig(
        level=logging.DEBUG,
        format="{%(filename)s:%(lineno)d} %(levelname)s - %(message)s",
        handlers=[
            logging.FileHandler(f"{pathlib.Path(__file__).stem}.log"),
            logging.StreamHandler(sys.stdout),
        ],
    )
    lst = get_words(count=2)
    out = "".join(lst)
    logging.debug(out)
    return out


if __name__ == "__main__":
    main()
